<?php
/**
 * Displays the translations page for posts
 */

if ( ! defined( 'ABSPATH' ) ) {exit;} // Don't access directly
use Falang\Core\Falang_Core;
use Falang\Model\Falang_Model;
use Falang\Translator\TranslatorYandex;
use Falang\Factory\TranslatorFactory;


$original_post = get_post($falang_original_post_id);
$falang_model = new Falang_Model();

if ($falang_model->get_option('enable_service')){
	TranslatorFactory::getTranslator($falang_target_language_locale);
}

?>

    <h2><?php echo sprintf('%1$s : %2$s', esc_html__( 'Translations Post', 'falang' ), $original_post->post_title); ?></h2>
    <form id="edit-translation" method="post" action="<?php echo $falang_form_action; ?>" class="validate">
        <div class="action-btn">
            <div class="cancel-edit">
                <a class="button button-primary" href="<?php echo $falang_cancel_action; ?>"><?php echo __( 'Cancel', 'falang' );?> </a>
            </div>
            <?php submit_button( __( 'Save', 'falang' ) ); ?>
        </div>

        <div class="info">
            <b><?php echo __( 'Target language : ', 'falang' ).$falang_target_language_locale;?></b>
            <br/>
	        <?php echo __('Published', 'falang'); ?>
            <!-- value not submited when unchecked-->
            <input type="checkbox" name="published"  id="published" value="1" <?php echo $falang_post->is_published($falang_target_language_locale) ? ' checked' : ''; ?>/>
	    </div>
        <div id="col-container">
            <div class="col-title">
                <div class="col-target">
                    <h3><?php echo esc_html__( 'Translations Destination', 'falang' ); ?></h3>
                </div><!-- col-target -->
                <div class="col-action">
                    <h3><?php echo esc_html__( 'Action', 'falang' ); ?></h3>
                </div><!-- col-action -->
                <div class="col-source">
                    <h3><?php echo esc_html__( 'Translations Source', 'falang' ); ?></h3>
                </div><!-- col-source -->
            </div>
                <?php foreach ($falang_post->fields as $key) { ?>
                    <?php $search_metakey = Falang_Core::get_prefix($falang_target_language_locale).$key?>
                    <?php $previous_value = isset($falang_post->metakey[$search_metakey])?$falang_post->metakey[$search_metakey]:''; ?>
                    <div class="row">

                        <h2><?php echo $key ?></h2>

                        <div class="col-target">
                            <?php if ($key == 'post_content') { ?>
	                            <?php echo wp_editor($previous_value[0],$key);?>
                            <?php } else { ?>
                                <input type="text" name="<?php echo $key; ?>" id="<?php echo $key; ?>" value="<?php echo $previous_value[0]; ?>">
                            <?php } ?>
                        </div><!-- col-target -->
                        <div class="col-action">
                            <button class="button-secondary button-copy" onclick="copyToTranslation('<?php echo $key;?>','copy');return false;" title="<?php  echo __( 'Copy', 'falang' ) ?>"><?php echo  __( 'Copy', 'falang' ) ?></button>
                            <!-- add yandex button -->
		                    <?php if ($falang_model->get_option('enable_service') == '1') { ?>
                                <button class="button-secondary button-copy" onclick="copyToTranslation('<?php echo $key;?>','translate');return false;" title="<?php  echo __( 'Copy with yandex', 'falang' ) ?>"><?php echo  __( 'Yandex', 'falang' ) ?></button>
		                    <?php } ?>
                        </div><!-- col-action -->
                        <div class="col-source">
                            <!-- with wp_editor like post_content hide the orignal value (translate/copy problem encoding) -->
	                        <?php if ($key == 'post_content') { ?>
                                <div id="original_value_<?php echo $key;?>" name="original_value_<?php echo $key;?>" style="display:none" >
		                            <?php echo $original_post->{$key}; ?>
                                </div>
    	                        <?php echo wp_editor($original_post->{$key},'fake_original_value_'.$key,array('readonly' => true)); ?>
	                        <?php }  else { ?>
                                <div id="original_value_<?php echo $key;?>" name="original_value_<?php echo $key;?>">
	                                <?php echo $original_post->{$key}; ?>
                                </div>
                            <?php }  ?>
                        </div><!-- col-source -->
                    </div><!-- row -->
                <?php }//foreach ?>
	        <?php foreach ($falang_translated_metakeys as $key) { ?>
		        <?php $search_metakey = Falang_Core::get_prefix($falang_target_language_locale).$key?>
		        <?php $previous_value = isset($falang_post->metakey[$search_metakey])?$falang_post->metakey[$search_metakey]:''; ?>
                <div class="row">
                    <h2><?php echo $key ?></h2>
                    <div class="col-target">
                            <input type="text" name="<?php echo $key; ?>" id="<?php echo $key; ?>" value="<?php echo $previous_value[0]; ?>">
                    </div><!-- col-target -->
                    <div class="col-action">
                        <button class="button-secondary button-copy" onclick="copyToTranslation('<?php echo $key;?>','copy');return false;" title="<?php  echo __( 'Copy', 'falang' ) ?>"><?php echo  __( 'Copy', 'falang' ) ?></button>
                        <!-- add yandex button -->
				        <?php if ($falang_model->get_option('enable_service') == '1') { ?>
                            <button class="button-secondary button-copy" onclick="copyToTranslation('<?php echo $key;?>','translate');return false;" title="<?php  echo __( 'Copy with yandex', 'falang' ) ?>"><?php echo  __( 'Yandex', 'falang' ) ?></button>
				        <?php } ?>
                    </div><!-- col-action -->
                    <div class="col-source">
                            <div id="original_value_<?php echo $key;?>" name="original_value_<?php echo $key;?>">
						        <?php echo $original_post->{$key}; ?>
                            </div>
                    </div><!-- col-source -->
                </div><!-- row -->
	        <?php }//foreach metakeay ?>
                <div class="row">
                    <input type="hidden" name="action" value="falang_save_post" />
                    <input type="hidden" name="target_language" value="<?php echo $falang_target_language_locale?>">
                    <input type="hidden" name="post_id" value="<?php echo $falang_original_post_id?>">
                    <div class="action-btn">
                        <div class="cancel-edit">
                            <a class="button button-primary" href="<?php echo $falang_cancel_action; ?>"><?php echo __( 'Cancel', 'falang' );?> </a>
                        </div>
                        <?php submit_button( __( 'Save', 'falang' ) ); ?>
                    </div>
                </div>
        </div><!-- col-container -->
    </form>



