<?php
/**
 * Created by PhpStorm.
 * User: Stéphane
 * Date: 25/06/2019
 * Time: 10:59
 */

namespace Falang\Core;


use Falang\Model\Falang_Model;

class Language_Switcher {

	var $params = '';

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	public function __construct( $params = '' ) {
		$this->params = $params;
		add_shortcode( 'falangsw', 'falang_language_switcher' );
	}

	public function display_switcher() {
		$args = wp_parse_args( $this->params, array(
			'echo' => false,
		) );

		$links = $this->get_links();
		$total = count( $links );
		$output = '';

		//TODO use $total to display fist and last @see bogo
		foreach ($links as $link) {
			$class = array();
			$label = $link['native_name'] ? $link['native_name'] : $link['title'];
			$title = $link['title'];

			if ( get_locale() == $link['locale'] ) {
				$class[] = ' current';
			}

			$file = FALANG_DIR.'/flags/' . $link['flag'] . '.png';
			if ( ! empty( $link['flag'] ) && file_exists( $file) ) {
				$flag_url = plugins_url( 'flags/'.$link['flag'] . '.png', FALANG_FILE );
			}

			//if hide name reset it.
			if (!empty($this->params) &&  $this->params['display_name'] != '1') {
				$label = '';
			}

			$positioning_h = (!empty($this->params['positioning']))? $this->params['positioning'] == 'h':false;//true if horisontal

			$position_class = $positioning_h ? 'lang-h':'lang-v';

			//display flag
			if (!empty($this->params) &&  $this->params['display_flags'] == '1') {
				$li = sprintf(
					'<li><a class="%1$s" href="%2$s"><img src="%3$s" alt="%4$s"/>%5$s</a></li>',
					implode(" ", $class),
					$link['href'],
					$flag_url,
					$title,
					$label)
				;
			} else {
				$li = sprintf( '<li><a class="%1$s" href="%2$s">%3$s</a></li>', implode(" ", $class), $link['href'] , $label);
			}

			$output .= $li . "\n";
		}

		$output = '<ul class="falang-language-switcher '. $position_class.'">' . $output . '</ul>' . "\n";

		//$output = apply_filters( 'falang_language_switcher', $output, $args );

		if ( $args['echo'] ) {
			echo $output;
		} else {
			return $output;
		}
	}

	public function get_links() {
		global $wp_query;
		$fmodel = new Falang_Model();
		$links = array();

//		$args   = wp_parse_args( $this->args, array() );
		$locale = get_locale();

		$is_singular  = false;
		$translations = array();


		if ( is_singular() || ! empty( $wp_query->is_posts_page ) ) {
			$is_singular = true;
		}

//		var_dump( $is_singular );

		$fpost     = new Post( get_queried_object_id() );
		$languages = $fmodel->get_languages_list();

		foreach ( $languages as $language ) {

			$published = $fpost->is_published( $language->locale );

			$link = array(
				'locale'      => $language->locale,
				'slug'        => $language->slug,
				'title'       => $language->name,
				'native_name' => $language->name,
				'flag'        => $language->flag_code,
				'href'        => '',
			);

			if ( $is_singular ) {
				if ( $locale != $language->locale ) {

//				     && ! empty( $translations[$language->locale] )
////				     && 'publish' == get_post_status( $translations[$language->locale] ) ) {
					//$link['href'] = get_permalink( $translations[$language->locale] );
					$link['href'] = $this->get_translated_url( $language );

				}
			} else {
				$link['href'] = $this->get_translated_url( $language );
//				if ( $locale != $language->locale ) {
//					$link['href'] = $this->get_translated_url( $language );
//				}
			}

			$links[] = $link;

		}

		return $links;
	}

	//TODO put this in class-falang or falang_core
	private function get_translated_url( $language ) {
		$args = array(
			'using_permalinks' => (bool) get_option( 'permalink_structure' ),
		);
		global $wp_query, $wp_rewrite;

		$query_object = get_queried_object();

		global $falang_core;

		$falang_core->set_language($language); // -> pretend this is the current language

		$link = '';

		if ( is_category() || is_tag() || is_tax() ) {

			$original_term = get_term( $query_object->term_id, $query_object->taxonomy );

			$link = get_term_link( $original_term, $original_term->taxonomy );

		} else if ( is_post_type_archive() ) {

			$link = get_post_type_archive_link( get_post_type() );

		} else if ( is_singular() || $wp_query->is_posts_page ) {

			$link = get_permalink( $query_object->ID );

		} else if ( is_date() ) {

			if ( is_day() ) {
				$link = get_day_link( get_query_var( 'year' ), get_query_var( 'monthnum' ), get_query_var( 'day' ) );
			} else if ( is_month() ) {
				$link = get_month_link( get_query_var( 'year' ), get_query_var( 'monthnum' ) );
			} else if ( is_year() ) {
				$link = get_year_link( get_query_var( 'year' ) );
			} else {
				$link = home_url( '/' );
			}

		} else if ( is_author() ) {

			$link = get_author_posts_url( get_user_by( 'slug', get_query_var( 'author_name' ) )->ID );

		} else if ( is_search() ) {

			$link = get_search_link( get_search_query() );

		} else { // is_home, is_404

			$link = home_url( '/' );

		}

		$falang_core->restore_language();

		return $link;
	}


}